function SCORM(navEngineReference)
{
	//Reference to the navigation engine:
	this.nav = navEngineReference;
	
	//Should SCORM calls be processed?
	this.scormEnabled = true;
	
	//Default completion status:
	this.completionStatus = "incomplete";
	
	//Suspend data, used to store visited states of screens:
	this.suspendData = "";
	
	//Default bookmark:
	this.bookmark = "";
}

//Begin the SCO.  Return "cmi.core.entry" value.:
SCORM.prototype.beginSCO = function()
{	
	if(!this.scormEnabled) return null;
	
	//Get start time:
	this.sessionStartTime = new Date().getTime();
	
	//Disable SCORM calls if we cannot successfully handshake with the LMS:
	var handshakeSuccess = doLMSInitialize();
	if(handshakeSuccess == false){
		this.scormEnabled = false;
	}
	
	//Determine if we are resuming a previous attempt:
	var entry = this.get("cmi.core.entry");
	return entry;
}

SCORM.prototype.getSuspendData = function(){
	return this.get("cmi.suspend_data");
}

SCORM.prototype.getBookmark = function(){
	return this.get("cmi.core.lesson_location");
}

SCORM.prototype.setBookmark = function(bookmark){
	this.bookmark = bookmark;
}

SCORM.prototype.setCompletionStatus = function(statusStr){
	this.completionStatus = statusStr;
}

//Wrap the doLMSGetValue API method:
SCORM.prototype.get = function(variableName)
{
	if(!this.scormEnabled) return null;
	return doLMSGetValue(variableName);
}

//Wrap the doLMSSetValue API method:
SCORM.prototype.set = function(variableName, variableValue){
	if(!this.scormEnabled) return null;
	doLMSSetValue(variableName, variableValue);
}

//End the SCO:
SCORM.prototype.endSCO = function()
{
	if(!this.scormEnabled) return null;
	
	//Get session end time:
	this.sessionEndTime = new Date().getTime();
	
	//Calculate session time in miliseconds:
	var sessionTime = Math.abs(this.sessionStartTime - this.sessionEndTime);
	//Get the SCORM formatted session time string:
	var sessionTimeSCORMFormattedStr = this.getSessionTimeStr(sessionTime);
	
	//Communicate the session time via SCORM call to the LMS:
	this.set("cmi.core.session_time", sessionTimeSCORMFormattedStr);
	
	//Set bookmark:
	this.set("cmi.core.lesson_location", this.bookmark);
	
	//Set lesson completion status:
	this.set("cmi.core.lesson_status", this.completionStatus);
	
	//Set exit status to suspend if the SCO is not yet completed:
	var exitStatus = (this.completionStatus == "completed")? "": "suspend";
	if(exitStatus == "suspend"){
		//If suspending, set suspend data:
		this.set("cmi.suspend_data", this.suspendData);
	}
	
	this.set("cmi.core.exit", exitStatus);
	
	doLMSCommit();
	doLMSFinish();	
}

//Converts a session time in miliseconds to a SCORM formatted session time string:
SCORM.prototype.getSessionTimeStr = function(calculatedTime)
{	
	var totalHours = Math.floor(calculatedTime/1000/60/60);
	calculatedTime = calculatedTime - totalHours*1000*60*60
	if ( totalHours < 1000 && totalHours > 99 )
	{
		totalHours = "0"+totalHours.toString();
	}
	else if ( totalHours < 100 && totalHours > 9 )
	{
		totalHours = "00"+totalHourstoString();
	} 
	else if ( totalHours < 10 )
	{
		totalHours = "000"+totalHours.toString();
	}
	
	var totalMinutes = Math.floor(calculatedTime/1000/60);
	calculatedTime = calculatedTime - totalMinutes*1000*60;
	if ( totalMinutes < 10 )
	{
		totalMinutes = "0"+totalMinutes.toString();
	}
	
	var totalSeconds = Math.floor(calculatedTime/1000);
	if ( totalSeconds < 10 )
	{
		totalSeconds = "0"+totalSeconds.toString();
	}
	
	var sessionTime = totalHours + ":";
		sessionTime += totalMinutes + ":";
		sessionTime += totalSeconds;
		
	return sessionTime;
}