/*
	Example activityData object:
	var activityData = {
		activityText: "<p class=\"greenText\">Instructions: Identify whether each statement on the right is either true or false by using the dropdown menus, and then select the "Submit" button.</p>",
		menuOptions: ["True", "False"],
		lures: [{answer: "True", text: "When you use extensive quotations instead of paraphrasing the content of the author's ideas, this suggests that you cannot explain how the material being quoted relates to your research."},
		{answer:"True", text:"Any quotation of 40+ words must be blocked as an indented paragraph with no quotation marks."},
		{answer:"False", text:"Long quotations can be single-spaced."},
		{answer:"True", text:"Direct quotations should be used only if the words quoted are unique and impossible to paraphrase."},
		{answer:"True", text:"If you paraphrase the words of another author, but do not quote him/her directly, you must identify and credit the author in your ARP."}],
		feedbackCorrect: "<p class=\"feedback correct\">Correct!</p>",
		feedbackIncorrect: ["<p class=\"feedback incorrect\">Incorrect. Please try again.</p>", "<p class=\"feedback incorrect\">Incorrect. Please try again.</p>", "<p class=\"feedback incorrect\">Incorrect. Remember that any quotation of more than 40 words must be blocked as an indented paragraph with no quotation marks and double-spaced. Direct quotations should only be used if it is impossible to paraphrase the author's meaning, as overuse of direct quotations suggests that you cannot explain how the material being quoted relates to your research. Finally, when you paraphrase the words of another author within your ARP, you must always properly identify and credit that author.</p><p>Please revisit Slide XX for more information.</p>"],
		maxAttempts:3,
		randomizeLures: true
	};
*/
function Matching(activityContainer, activityData){
	this.activityContainer = activityContainer;
	this.activityData = activityData;
	this.attempt = 0;
	this.feedbackWindow = null;
	this.currentFeedback = "";
	
	//Open the feedback window if necessary and then trigger the "writeFeedbackToPopup" private method once the window is ready:
	this.showFeedback = function(feedbackStr){
		this.currentFeedback = feedbackStr;
		if(this.feedbackWindow) this.feedbackWindow.close();
		this.feedbackWindow = framework.createPopupWindow("../common/html/feedback.html", "feedbackWindow", 550, 230);
		this.feedbackWindow.focus();		
	};
	
	//When the activity is completed:
	this.onActivityCompleted = function(){
		framework.clearRoadblock();
		$('#btnSubmit').prop('disabled', true);		
	}

	//Check the answer:
	this.checkAnswer = function(){
		//Increment the attempt count:
		this.attempt++;
		
		//Detect success:
		var success = true;
		
		//Discard incorrect answers any incorrectly checked boxes and discard any incorrect selections (any occurance results in activity sucess = false):
		$(this.activityContainer).find("select").each(function(){
			if($(this).find("option:selected").text() != $(this).attr("correct")) success = false;
		});

		//If correct response:
		if(success == true){
			this.showFeedback(this.activityData.feedbackCorrect);
			this.onActivityCompleted();
			return;
		}
		
		//If incorrect response:
		else if(success == false)
		{
			this.showFeedback(this.activityData.feedbackIncorrect[this.attempt -1]);
			//If attempts exceeeded:
			if(this.attempt >= this.activityData.maxAttempts){
				//Show correct answer:
				$(this.activityContainer).find("select").each(function(){
					var selectMenu = this;
					var correctAnswer = $(selectMenu).attr("correct");
					$(selectMenu).val(correctAnswer);
					$(selectMenu).find("option:selected").addClass("correctAnswer");
				});
				this.onActivityCompleted();
			}
		}		
	}
	
}

//Initialize the activity:
Matching.prototype.initialize = function(){
	//Utility function to randomize an array:
	function shuffleArray(array) {
		for (var i = array.length - 1; i > 0; i--) {
			var j = Math.floor(Math.random() * (i + 1));
			var temp = array[i];
			array[i] = array[j];
			array[j] = temp;
		}
	}
	
	//Randomize lures if specified:
	if(this.activityData.randomizeLures == "true" || this.activityData.randomizeLures == true){
		shuffleArray(this.activityData.lures);
	}
	
	var dropDownMarkup = "";
	$(this.activityData.menuOptions).each(function(index){
		dropDownMarkup += "<option>" + this + "</option>";
	});
	
	//Generate activity markup and inject into the container DOM element:
	var lureMarkupStr = "<table class='activityTable'>";
	$(this.activityData.lures).each(function(index){
		var lureAnswer = this.answer;
		var lureText = this.text;
		lureMarkupStr += "<tr><td><select id='lureMenu" + index + "' correct='" + this.answer +"'>" + dropDownMarkup + "</select></td><td>" + this.text + "</td></tr>";
	});
	
	lureMarkupStr += "</table>";
	var buttonMarkupStr = "<button id=\"btnSubmit\">Submit</button>";
	$(this.activityContainer).empty().append(this.activityData.activityText).append(lureMarkupStr).append(buttonMarkupStr);
	
	//If debug mode is active, start at correct answer:
	if(framework.debugMode == true){
		$(this.activityContainer).find("select").each(function(){
			var selectMenu = this;
			var correctAnswer = $(selectMenu).attr("correct");
			$(selectMenu).find("option").each(function(){
				if($(this).text() == correctAnswer){
					$(this).addClass("correctAnswer");
				}
			});
		});
	}
	
	//When the submit button is pressed, check the answer:
	$("#btnSubmit").click($.proxy(this.checkAnswer, this));		
}

//Invoked when the feedback popup window DOM is ready (see popup.js):
Matching.prototype.onFeedbackWindowReady = function(){
	$(this.feedbackWindow.document).contents().find("#popupBody").html(this.currentFeedback);	
}