/*
	Example activityData object:
	var activityData = {
		activityText: "<p class=\"greenText\">Instructions: Which of these are plants? Select the best answer, and then select the Submit button.</p>",
		lures: ["Cat",
				"*Fern",
				"*Orchid",
				"Dog"],
		feedbackCorrect: "Correct",
		feedbackIncorrect: ["Incorrect Feedback 1", "Incorrect Feedback 2", "Incorrect Feedback 3"],
		maxAttempts:3,
		randomizeLures: true
	}
*/
function MultipleSelect(activityContainer, activityData){
	this.activityContainer = activityContainer;
	this.activityData = activityData;
	this.attempt = 0;
	this.feedbackWindow = null;
	this.currentFeedback = "";
	
	//Open the feedback window if necessary and then trigger the "writeFeedbackToPopup" private method once the window is ready:
	this.showFeedback = function(feedbackStr){
		this.currentFeedback = feedbackStr;
		if(this.feedbackWindow) this.feedbackWindow.close();
		this.feedbackWindow = framework.createPopupWindow("../common/html/feedback.html", "feedbackWindow", 550, 230);
		this.feedbackWindow.focus();		
	};
	
	//When the activity is completed:
	this.onActivityCompleted = function(){
		framework.clearRoadblock();
		$('#btnSubmit').prop('disabled', true);		
	}

	//Check the answer:
	this.checkAnswer = function(){
		//Increment the attempt count:
		this.attempt++;
		
		//Detect success:
		var success = true;
		
		//Discard incorrect answers any incorrectly checked boxes and discard any incorrect selections (any occurance results in activity sucess = false):
		$("input[type=checkbox][value=0]:checked").each(function(){
			this.checked = false;
			success = false;
		});
		
		//Also detect if there are any instances where a checkbox SHOULD be checked but wasn't checked (any occurance results in activity sucess = false):
		if($("input[type=checkbox][value=1]").not(":checked").length != 0){
			success = false;
		}

		//If correct response:
		if(success == true){
			this.showFeedback(this.activityData.feedbackCorrect);
			this.onActivityCompleted();
			return;
		}
		
		//If incorrect response:
		else if(success == false)
		{
			this.showFeedback(this.activityData.feedbackIncorrect[this.attempt -1]);
			//If attempts exceeeded:
			if(this.attempt >= this.activityData.maxAttempts){
				//Show correct answer:
				$('input[type=checkbox]').each(function(){
					this.checked = (this.value==1);
				});
				this.onActivityCompleted();
			}
		}		
	}
	
}

//Initialize the activity:
MultipleSelect.prototype.initialize = function(){
	//Utility function to randomize an array:
	function shuffleArray(array) {
		for (var i = array.length - 1; i > 0; i--) {
			var j = Math.floor(Math.random() * (i + 1));
			var temp = array[i];
			array[i] = array[j];
			array[j] = temp;
		}
	}
	
	//Randomize lures if specified:
	if(this.activityData.randomizeLures == "true" || this.activityData.randomizeLures == true){
		shuffleArray(this.activityData.lures);
	}
	
	//Generate activity markup and inject into the container DOM element:
	var lureMarkupStr = "<ul class=\"lureList spacedList\">";
	$(this.activityData.lures).each(function(index){
		var lureStr = this;
		var value = 0;			
		if(lureStr.charAt(0)=="*"){
			lureStr = lureStr.substring(1);
			value = 1;
		}
		lureMarkupStr += "<li><input type=\"checkbox\" value=\"" + value + "\"/><span class=\"lureText\">" + lureStr + "</span></li>"
	});
	
	lureMarkupStr += "</ul>";
	var buttonMarkupStr = "<button id=\"btnSubmit\">Submit</button>";
	$(this.activityContainer).empty().append(this.activityData.activityText).append(lureMarkupStr).append(buttonMarkupStr);

	//If debug mode is active, add correct answer styling:
	if(framework.debugMode == true){
		$("input[value=1]").parent().find("span.lureText").addClass("correctAnswer");
	}
	
	//When a radio button is selected, deselect others:
	$("input[type=radio]").change(function(){
		$("input[type=radio]").not(this).prop("checked",false);
	});
	
	//When the submit button is pressed, check the answer:
	$("#btnSubmit").click($.proxy(this.checkAnswer, this));		
}

//Invoked when the feedback popup window DOM is ready (see popup.js):
MultipleSelect.prototype.onFeedbackWindowReady = function(){
	$(this.feedbackWindow.document).contents().find("#popupBody").html(this.currentFeedback);	
}